@@ -17,6 +17,16 @@ class Changelog:
 
     def initLogs(self) -> None:
         """Fill the changelog."""
+        self.logs.append(
+            ChangelogEntry(5, 24, 2)
+            .addLine("Added \\x1b\\r as newline, just like claude (smort!)")
+        )
+        self.logs.append(
+            ChangelogEntry(5, 24, 1)
+            .addLine("Fixed broken symlinks crashing /send, added message ID")
+            .addLine("  to files sent with /send, symlinks are now sent as")
+            .addLine("  their location instead of their content")
+        )
         self.logs.append(
             ChangelogEntry(5, 24, 0)
             .addLine("PROMPT INJECTION UPDATE")
